@@ -16,8 +16,8 @@ running Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 55000 2008-08-07 00:03:20Z CJP $"
-__revision__ = "$Revision: 55000 $"
+__svnid__ = "$Id: Editra.py 56555 2008-10-28 20:31:28Z CJP $"
+__revision__ = "$Revision: 56555 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -29,6 +29,14 @@ import time
 import getopt
 import wx
 
+# The event handler mixin is now part of wxPython proper, but there hasn't
+# been an official release with it yet, so try to import the official module
+# but fallback to our own copy if it fails.
+try:
+    import wx.lib.eventStack as events
+except:
+    import extern.events as events
+
 # Due to some methods that were added in 2.8.3 being used in a large number
 # of places Editra has become incompatable with wxPython 2.8.1.1 and earlier.
 # TODO: add a message dialog to display this, or look into the cause of the
@@ -58,7 +66,6 @@ import updater
 import plugin
 import ed_ipc
 import ed_msg
-import extern.events as events
 
 #--------------------------------------------------------------------------#
 # Global Variables
@@ -136,6 +143,10 @@ class Editra(wx.App, events.AppEventHandlerMixin):
                     args.append(APP_CMD_OPEN_WINDOW)
 
                 rval = ed_ipc.SendCommands(args, profiler.Profile_Get('SESSION_KEY'))
+                # If sending the command failed then let the editor startup
+                # a new instance
+                if not rval:
+                    self._isfirst = True
             else:
                 self._log("[app][info] Starting Ipc server...")
                 # Set the session key and save it to the users profile so
@@ -146,8 +157,13 @@ class Editra(wx.App, events.AppEventHandlerMixin):
                 profiler.Profile_Set('ISBINARY', hasattr(sys, 'frozen'))
                 path = profiler.Profile_Get('MYPROFILE')
                 profiler.Profile().Write(path)
-                self._server = ed_ipc.EdIpcServer(self, profiler.Profile_Get('SESSION_KEY'))
-                self._server.start()
+                try:
+                    self._server = ed_ipc.EdIpcServer(self, profiler.Profile_Get('SESSION_KEY'))
+                    self._server.start()
+                except Exception, msg:
+                    self._log("[app][err] Failed to start ipc server")
+                    self._log("[app][err] %s" % str(msg))
+                    self._server = None
                 self._isfirst = True
         else:
             self._isfirst = True
@@ -162,6 +178,10 @@ class Editra(wx.App, events.AppEventHandlerMixin):
             del self.locale
             self.locale = None
 
+        # Check and set encoding if necessary
+        if not profiler.Profile_Get('ENCODING'):
+            profiler.Profile_Set('ENCODING', locale.getpreferredencoding())
+
         # Setup the Error Reporter
         if profiler.Profile_Get('REPORTER', 'bool', True):
             sys.excepthook = dev_tool.ExceptionHook
@@ -263,7 +283,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
             win = self.GetActiveWindow()
             if win is None:
                 return win
-                
+
         return win.GetNotebook().GetCurrentCtrl()
 
     def GetMainWindows(self):
@@ -314,7 +334,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         """
         return self._lock
 
-    def IsOnlyInstance(self):   
+    def IsOnlyInstance(self):
         """Check if this app is the the first instance that is running
         @return: bool
 
@@ -339,10 +359,10 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         window = self.GetTopWindow()
         if getattr(window, '__name__', '') == "MainWindow":
             try:
+                self._log("[app][info] MacOpenFile Fired")
                 encoding = sys.getfilesystemencoding()
                 window.DoOpen(ed_glob.ID_COMMAND_LINE_OPEN,
                               ed_txt.DecodeString(filename, encoding))
-                self._log("[app][info] MacOpenFile Fired")
             except Exception, msg:
                 self._log("[app][err] Failed to open drop file: %s" % str(msg))
                 pass
@@ -430,10 +450,10 @@ class Editra(wx.App, events.AppEventHandlerMixin):
 
         """
         if evt.GetId() in [ed_glob.ID_CLOSE, ed_glob.ID_CLOSE_WINDOW]:
-            for window in self._windows.values():
-                if hasattr(window[0], 'IsActive') and window[0].IsActive():
-                    if hasattr(window[0], 'Close'):
-                        window[0].Close()
+            for window in wx.GetTopLevelWindows():
+                if hasattr(window, 'IsActive') and window.IsActive():
+                    if hasattr(window, 'Close'):
+                        window.Close()
                     break
         else:
             evt.Skip()
@@ -573,9 +593,22 @@ def InitConfig():
     @postcondition: all configuration data is set
 
     """
-    ed_glob.CONFIG['PROFILE_DIR'] = util.ResolvConfigDir("profiles")
+    # Look for a profile directory on the system level. If this directory exists
+    # Use it instead of the user one. This will allow for running Editra from
+    # a portable drive or for system administrators to enforce settings on a
+    # system installed version.
+    config_base = util.ResolvConfigDir(u'.Editra', True)
+    if os.path.exists(config_base):
+        ed_glob.CONFIG['CONFIG_BASE'] = config_base
+        ed_glob.CONFIG['PROFILE_DIR'] = os.path.join(config_base, u"profiles")
+        ed_glob.CONFIG['PROFILE_DIR'] += os.sep
+    else:
+        ed_glob.CONFIG['PROFILE_DIR'] = util.ResolvConfigDir("profiles")
+
+    # Check for if config directory exists and if profile is from the current
+    # running version of Editra.
     profile_updated = False
-    if util.HasConfigDir():
+    if util.HasConfigDir() and os.path.exists(ed_glob.CONFIG['PROFILE_DIR']):
         if profiler.ProfileIsCurrent():
             profiler.Profile().Load(profiler.GetProfileStr())
         else:
@@ -593,7 +626,12 @@ def InitConfig():
             if mode == 'GUI_DEBUG':
                 profiler.Profile_Set('MODE', 'DEBUG')
 
+            # This key has been removed so clean it from old profiles
             profiler.Profile_Del('LASTCHECK')
+
+            # Print modes don't use strings anymore
+            if isinstance(profiler.Profile_Get('PRINT_MODE'), basestring):
+                profiler.Profile_Set('PRINT_MODE', ed_glob.PRINT_BLACK_WHITE)
             #---- End Temporary Profile Adaptions ----#
 
             # Write out updated profile
