@@ -6,14 +6,14 @@
 # License: wxWindows License                                                  #
 ###############################################################################
 
-""" Editra Development Tools 
-@author: Cody Precord
+""" Editra Development Tools
+Tools and Utilities for debugging and helping with development of Editra.
 @summary: Utility function for debugging the editor
 
 """
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: dev_tool.py 51931 2008-02-20 08:09:38Z CJP $"
-__revision__ = "$Revision: 51931 $"
+__svnid__ = "$Id: dev_tool.py 55939 2008-09-29 02:11:47Z CJP $"
+__revision__ = "$Revision: 55939 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -42,6 +42,19 @@ def DEBUGP(statement):
     """Prints debug messages and broadcasts them on the log message channel.
     Subscribing a listener with any of the EDMSG_LOG_* types will recieve its
     messages from this method.
+
+      1. Formatting
+        - [object/module name][msg_type] message string
+
+      2. Message Type:
+        - [err]  : Notes an exception or error condition (high priority)
+        - [warn] : Notes a error that is not severe (medium priority)
+        - [info] : General information message (normal priority)
+        - [evt]  : Event related message (normal priority)
+
+    Example:
+      >>> DEBUGP("[ed_main][err] File failed to open")
+
     @param statement: Should be a formatted string that starts with two
                       identifier blocks. The first is used to indicate the
                       source of the message and is used as the primary means
@@ -49,17 +62,6 @@ def DEBUGP(statement):
                       this is used to indicate the priority of the message and
                       is used as the secondary means of filtering.
 
-        1. Formatting
-            - [object/module name][msg_type] message string
-
-        2. Message Type:
-            - [err]  : Notes an exception or error condition (high priority)
-            - [warn] : Notes a error that is not severe (medium priority)
-            - [info] : General information message (normal priority)
-            - [evt]  : Event related message (normal priority)
-
-    @example: DEBUGP([ed_main][err] File failed to open)
-
     """
     # Create a LogMsg object from the statement string
     lbls = [lbl.strip() for lbl in RE_LOG_LBL.findall(statement)]
@@ -159,42 +161,27 @@ class LogMsg:
 
     @property
     def Expired(self):
-        """Has this message already been retrieved
-        @return: bool
-
-        """
+        """Has this message already been retrieved"""
         return not self._ok
 
     @property
     def Origin(self):
-        """Where the message came from
-        @return: string
-
-        """
+        """Where the message came from"""
         return self._msg['msrc']
 
     @property
     def TimeStamp(self):
-        """Property for accessing timestamp
-        @return: long int
-
-        """
+        """Property for accessing timestamp"""
         return self._msg['tstamp']
 
     @property
     def Type(self):
-        """The messages level type
-        @return string (err, warn, info, evt)
-
-        """
+        """The messages level type"""
         return self._msg['lvl']
 
     @property
     def Value(self):
-        """Returns the message part of the log string
-        @return: string
-
-        """
+        """Returns the message part of the log string"""
         return self._msg['mstr']
 
 #-----------------------------------------------------------------------------#
@@ -205,6 +192,9 @@ def EnvironmentInfo():
 
     """
     info = list()
+    info.append("#---- Notes ----#")
+    info.append("Please provide additional information about the crash here")
+    info.extend(["", "", ""])
     info.append("#---- System Information ----#")
     info.append("%s Version: %s" % (ed_glob.PROG_NAME, ed_glob.VERSION))
     info.append("Operating System: %s" % wx.GetOsDescription())
@@ -236,7 +226,11 @@ def EnvironmentInfo():
                     if ext not in ftypes:
                         ftypes.append(ext)
         else:
-            info.append(u"%s=%s" % (key, str(val)))
+            try:
+                info.append(u"%s=%s" % (key, str(val)))
+            except UnicodeDecodeError:
+                continue
+
     info.append(u"FTYPES=%s" % str(ftypes))
     info.append("#---- End Runtime Variables ----#")
 
@@ -255,12 +249,10 @@ def ExceptionHook(exctype, value, trace):
     print ftrace
 
     # If abort has been set and we get here again do a more forcefull shutdown
-    
     if ErrorDialog.ABORT:
         os._exit(1)
 
     # Prevent multiple reporter dialogs from opening at once
-    
     if not ErrorDialog.REPORTER_ACTIVE and not ErrorDialog.ABORT:
         ErrorDialog(ftrace)
 
