@@ -14,17 +14,17 @@ access point for all common variables in the project.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_glob.py 56026 2008-10-02 02:58:38Z CJP $"
-__revision__ = "$Revision: 56026 $"
+__svnid__ = "$Id: ed_glob.py 56611 2008-10-31 03:43:03Z CJP $"
+__revision__ = "$Revision: 56611 $"
 
 __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN',
             'ID_CLOSE', 'ID_CLOSEALL', 'ID_SAVE', 'ID_SAVEAS', 'ID_SAVEALL',
             'ID_SAVE_PROFILE', 'ID_LOAD_PROFILE', 'ID_PRINT', 'ID_PRINT_PRE',
             'ID_PRINT_SU', 'ID_EXIT', 'ID_UNDO', 'ID_REDO', 'ID_CUT',
-            'ID_COPY', 'ID_PASTE', 'ID_SELECTALL', 'ID_ADD_BM', 'ID_DEL_BM',
+            'ID_COPY', 'ID_PASTE', 'ID_SELECTALL', 'ID_ADD_BM',
             'ID_DEL_ALL_BM', 'ID_LINE_AFTER', 'ID_LINE_BEFORE', 'ID_CUT_LINE',
-            'ID_COPY_LINE', 'ID_JOIN_LINES', 'ID_TRANSPOSE', 'ID_FIND',
-            'ID_FIND_REPLACE', 'ID_QUICK_FIND', 'ID_PREF', 'ID_ZOOM_OUT',
+            'ID_COPY_LINE', 'ID_JOIN_LINES', 'ID_TRANSPOSE',
+            'ID_QUICK_FIND', 'ID_PREF', 'ID_ZOOM_OUT',
             'HOME_PAGE', 'CONTACT_MAIL', 'ID_ZOOM_IN', 'ID_ZOOM_NORMAL',
             'ID_SHOW_EDGE', 'ID_SHOW_EOL', 'ID_SHOW_LN', 'ID_SHOW_WS',
             'ID_PERSPECTIVES', 'ID_INDENT_GUIDES', 'ID_VIEW_TOOL',
@@ -37,9 +37,9 @@ __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN',
             'ID_PLUGMGR', 'ID_STYLE_EDIT', 'ID_MACRO_START', 'ID_MACRO_STOP',
             'ID_MACRO_PLAY', 'ID_ABOUT', 'ID_HOMEPAGE', 'ID_CONTACT',
             'ID_COMMAND_BAR', 'ID_DOCUMENTATION', 'ID_COMMAND',
-            'ID_CLOSE_WINDOW', 'ID_USE_SOFTTABS', 'ID_DUP_LINE', 'ID_TRANSLATE',
+            'ID_USE_SOFTTABS', 'ID_DUP_LINE', 'ID_TRANSLATE',
             'I18N_PAGE', 'ID_GOTO_MBRACE', 'ID_HLCARET_LINE', 'ID_SHOW_SB',
-            'ID_REVERT_FILE', 'ID_RELOAD_ENC', 'ID_FIND_NEXT', 'ID_DOCPROP'
+            'ID_REVERT_FILE', 'ID_RELOAD_ENC', 'ID_DOCPROP'
 ]
 
 #---- Project Info ----#
@@ -55,15 +55,7 @@ from info import *
 import wx
 
 #---- WX Compatibility Hacks ----#
-# GetText is not available in 2.9 but GetItemLabel is not available pre 2.8.6
-if wx.VERSION < (2, 8, 6, 0, ''):
-    wx.MenuItem.GetItemLabel = wx.MenuItem.GetText
-    wx.MenuItem.GetItemLabelText = wx.MenuItem.GetLabel
-
-# HACK temporary bandaid to allow the the program to run until a replacement
-#      for this method can be found.
-if wx.VERSION >= (2, 9, 0, 0, ''):
-    wx.Brush.MacSetTheme = lambda x, y: x
+import wxcompat
 
 #---- Configuration Locations ----#
 # Values set when main loads
@@ -137,6 +129,7 @@ ID_PREF          = wx.ID_PREFERENCES
 # Prefrence Dlg Ids
 ID_PREF_LANG     = wx.NewId()
 ID_PREF_AALIAS   = wx.NewId()
+ID_PREF_AUTOTRIM = wx.NewId()
 ID_PREF_CHKMOD   = wx.NewId()
 ID_PREF_CHKUPDATE = wx.NewId()
 ID_PREF_DLEXER   = wx.NewId()
@@ -298,6 +291,7 @@ ID_2_PROF = {
              ID_PREF_LANG         : 'LANG',
              ID_REPORTER          : 'REPORTER',
              ID_SYNTAX            : 'SYNTAX',
+             ID_PREF_AUTOTRIM     : 'AUTO_TRIM_WS',
              ID_PREF_DLEXER       : 'DEFAULT_LEX',
              ID_PREF_ENCODING     : 'ENCODING',
              ID_PREF_SYNTHEME     : 'SYNTHEME',
