@@ -15,8 +15,8 @@ main Ui component of the editor that contains all the other components.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 56027 2008-10-02 02:59:14Z CJP $"
-__revision__ = "$Revision: 56027 $"
+__svnid__ = "$Id: ed_main.py 56611 2008-10-31 03:43:03Z CJP $"
+__revision__ = "$Revision: 56611 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -39,6 +39,7 @@ import ed_print
 import ed_cmdbar
 import ed_statbar
 import ed_mdlg
+import prefdlg
 import syntax.syntax as syntax
 import generator
 import plugin
@@ -970,7 +971,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                 doc.SetEncoding(nenc)
                 success = ctrl.ReloadFile()[0]
                 if not success:
-                    msg= _("Failed to reload the file with: %(encoding)s") % dict(encoding=nenc)
+                    msg = _("Failed to reload the file with: %(encoding)s") % dict(encoding=nenc)
                     wx.MessageBox(msg, style=wx.OK|wx.ICON_ERROR)
                     doc.SetEncoding(cenc)
                     ctrl.ReloadFile()
@@ -1236,14 +1237,11 @@ def OnAbout(evt):
 
 def OnPreferences(evt):
     """Open the Preference Panel
-    @note: The dialogs module is not imported until this is
-           first called so the first open may lag a little.
     @param evt: Event fired that called this handler
     @type evt: wxMenuEvent
 
     """
     if evt.GetId() == ID_PREF:
-        import prefdlg
         win = wx.GetApp().GetWindowInstance(prefdlg.PreferencesDialog)
         if win is not None:
             win.Raise()
