@@ -14,8 +14,8 @@ for managing keybindings and profiles is also provided by this module.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_menu.py 55013 2008-08-07 19:37:52Z CJP $"
-__revision__ = "$Revision: 55013 $"
+__svnid__ = "$Id: ed_menu.py 56649 2008-11-02 17:19:34Z CJP $"
+__revision__ = "$Revision: 56649 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -282,10 +282,7 @@ class KeyBinder(object):
         @return: tuple
 
         """
-        if cls.cprofile is None:
-            return _DEFAULT_BINDING.get(item_id, None)
-        else:
-            return cls.keyprofile.get(item_id, None)
+        return cls.keyprofile.get(item_id, None)
 
     @classmethod
     def LoadDefaults(cls):
@@ -310,14 +307,26 @@ class KeyBinder(object):
                 util.Log("[keybinder][info] Loading KeyProfile: %s" % ppath)
                 for line in reader:
                     parts = line.split('=', 1)
+                    # Check that the line was formatted properly
                     if len(parts) == 2:
+                        # Try to find the ID value
                         item_id = _GetValueFromStr(parts[0])
                         if item_id is not None:
-                            keydict[item_id] = [ part.strip()
-                                                 for part in parts[1].split('+')
-                                                 if len(part.strip()) ]
-                            if parts[1].strip().endswith('++'):
-                                keydict[item_id].append('+')
+                            tmp = [ part.strip()
+                                    for part in parts[1].split('+')
+                                    if len(part.strip()) ]
+
+                            # Do some checking if the binding is valid
+                            nctrl = len([key for key in tmp
+                                         if key not in ('Ctrl', 'Alt', 'Shift')])
+                            if nctrl:
+                                keydict[item_id] = tmp
+                                if parts[1].strip().endswith('++'):
+                                    keydict[item_id].append('+')
+                            else:
+                                # Invalid key binding
+                                continue
+
                 reader.close()
                 KeyBinder.keyprofile = keydict
                 KeyBinder.cprofile = pname
@@ -356,18 +365,17 @@ class KeyBinder(object):
         @param keys: string or list of key strings
 
         """
-        if cls.cprofile is None:
-            util.Log("[keybinder][warn] No keyprofile has been loaded yet")
-        else:
-            if isinstance(keys, basestring):
-                keys = [ key.strip() for key in keys.split('+') ]
+        if isinstance(keys, basestring):
+            keys = [ key.strip() for key in keys.split('+') ]
 
-            if len(keys):
-                cls.keyprofile[item_id] = keys
-            elif cls.keyprofile.has_key(item_id):
-                del cls.keyprofile[item_id]
-            else:
-                pass
+        if len(keys):
+            # Set the binding
+            cls.keyprofile[item_id] = keys
+        elif cls.keyprofile.has_key(item_id):
+            # Clear the binding
+            del cls.keyprofile[item_id]
+        else:
+            pass
 
     @classmethod
     def SetProfileName(cls, pname):
@@ -487,6 +495,9 @@ class EdMenuBar(wx.MenuBar):
         filemenu.Append(ed_glob.ID_REVERT_FILE, _("Revert to Saved") + \
                         EdMenuBar.keybinder.GetBinding(ed_glob.ID_REVERT_FILE),
                         _("Revert file to last save point"))
+        filemenu.Append(ed_glob.ID_RELOAD_ENC, _("Reload with Encoding") + \
+                        u"..." + EdMenuBar.keybinder.GetBinding(ed_glob.ID_RELOAD_ENC),
+                        _("Reload the file with a specified encoding"))
         filemenu.AppendSeparator()
         pmenu = EdMenu()
         pmenu.Append(ed_glob.ID_SAVE_PROFILE, _("Save Profile") + \
@@ -590,6 +601,9 @@ class EdMenuBar(wx.MenuBar):
         editmenu.Append(ed_glob.ID_QUICK_FIND, _("&Quick Find") + \
                         EdMenuBar.keybinder.GetBinding(ed_glob.ID_QUICK_FIND),
                         _("Open the Quick Find Bar"))
+        editmenu.Append(ed_glob.ID_FIND_NEXT, _("Find Next") + \
+                        EdMenuBar.keybinder.GetBinding(ed_glob.ID_FIND_NEXT),
+                        _("Goto the next match"))
         editmenu.AppendSeparator()
         editmenu.Append(ed_glob.ID_PREF, _("Pr&eferences") + \
                         EdMenuBar.keybinder.GetBinding(ed_glob.ID_PREF),
@@ -887,7 +901,24 @@ class EdMenuBar(wx.MenuBar):
         """Reset all key bindings based on current binder profile"""
         for menu in self.GetMenus():
             for item in IterateMenuItems(menu[0]):
-                binding = EdMenuBar.keybinder.GetBinding(item.GetId())
+                item_id = item.GetId()
+                binding = EdMenuBar.keybinder.GetBinding(item_id)
+                if not len(binding):
+                    continue
+
+                # Verify binding and clear invalid ones from binder
+                tmp = [key.title() for key in binding.strip().split(u'+')]
+                nctrl = len([key for key in tmp
+                            if key not in ('Ctrl', 'Alt', 'Shift')])
+                if len(tmp) > 3 or not nctrl:
+                    EdMenuBar.keybinder.SetBinding(item_id, '')
+                    continue
+
+                # Reset the binding in the binder to ensure it is
+                # correctly formatted.
+                binding = u"\t" + u"+".join(tmp)
+                EdMenuBar.keybinder.SetBinding(item_id, binding)
+
                 clbl = item.GetText()
                 # Update the item if the shortcut has changed
                 if ('\t' in clbl and not clbl.endswith(binding)) or \
@@ -954,6 +985,7 @@ _DEFAULT_BINDING = { # File Menu
                      ed_glob.ID_TRANSPOSE : ("Ctrl", "T"),
                      ed_glob.ID_ADD_BM : ("Ctrl", "B"),
                      ed_glob.ID_FIND : ("Ctrl", "Shift", "F"),
+                     ed_glob.ID_FIND_NEXT : ("F3",),
                      ed_glob.ID_FIND_REPLACE : ("Ctrl", "R"),
                      ed_glob.ID_QUICK_FIND : ("Ctrl", "F"),
 
@@ -982,8 +1014,10 @@ _DEFAULT_BINDING = { # File Menu
 
 # Set some platform specific keybindigs
 if wx.Platform == '__WXMAC__':
-    _DEFAULT_BINDING[ed_glob.ID_NEXT_MARK] = ("Ctrl", "Right")
-    _DEFAULT_BINDING[ed_glob.ID_PRE_MARK] = ("Ctrl", "Left")
+    _DEFAULT_BINDING[ed_glob.ID_NEXT_MARK] = ("Ctrl", "Down")
+    _DEFAULT_BINDING[ed_glob.ID_PRE_MARK] = ("Ctrl", "Up")
+    _DEFAULT_BINDING[ed_glob.ID_FIND_NEXT] = ("Ctrl", "G")
+    _DEFAULT_BINDING[ed_glob.ID_GOTO_LINE] = ("Ctrl", "Shift", "E")
 elif wx.Platform == '__WXMSW__':
      # FIXME: On Windows if Tab is bound to a menu item it is no longer
      #        usable elsewhere such as in the stc control. On Mac/Gtk there
