@@ -7,21 +7,14 @@
 ###############################################################################
 
 """
-This file defines the notebook for containing the text controls for
-for editing text in Editra. The note book is a custom sublclass of
-FlatNotebook that allow for automatic page images and drag and dropping
-of tabs between open editor windows. The notebook is also primarly in
-charge of opening files that are requested by the user and setting up the
-text control to use them. For more information on the text controls used
-in the notebook see ed_stc.py
-
+This class implements Editra's main notebook control.
 @summary: Editra's main notebook class
 
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_pages.py 56031 2008-10-02 03:22:10Z CJP $"
-__revision__ = "$Revision: 56031 $"
+__svnid__ = "$Id: ed_pages.py 56613 2008-10-31 03:50:47Z CJP $"
+__revision__ = "$Revision: 56613 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -32,12 +25,11 @@ import wx
 # Editra Libraries
 import ed_glob
 from profiler import Profile_Get
-import ed_stc
+import ed_editv
 import syntax.synglob as synglob
 import syntax.syntax as syntax
 import ed_search
 import util
-import doctools
 import ed_msg
 import ed_txt
 import ed_mdlg
@@ -73,9 +65,10 @@ class EdPages(FNB.FlatNotebook):
 
         # Notebook attributes
         self.LOG = wx.GetApp().GetLog()
+        self.DocMgr = ed_editv.EdEditorView.DOCMGR
         self._searchctrl = ed_search.SearchController(self, self.GetCurrentCtrl)
-        self.DocMgr = doctools.DocPositionMgr(ed_glob.CONFIG['CACHE_DIR'] + \
-                                              os.sep + u'positions')
+        self._searchctrl.SetLookinChoices(Profile_Get('SEARCH_LOC',
+                                                      default=list()))
         self.pg_num = -1              # Track new pages (aka untitled docs)
         self.control = None
         self.frame = self.GetTopLevelParent() # MainWindow
@@ -234,7 +227,7 @@ class EdPages(FNB.FlatNotebook):
         @return: list of tuples
 
         """
-        return [(ed_glob.ID_FIND_NEXT, self._searchctrl.OnUpdateFindUI),]
+        return [(ed_glob.ID_FIND_NEXT, self._searchctrl.OnUpdateFindUI), ]
 
     def LoadSessionFiles(self):
         """Load files from saved session data in profile
@@ -245,12 +238,16 @@ class EdPages(FNB.FlatNotebook):
         """
         self._ses_load = True
         files = Profile_Get('LAST_SESSION')
+
+        # Open the files from the profile
         if files is not None:
             for fname in files:
                 if os.path.exists(fname) and os.access(fname, os.R_OK):
                     self.OpenPage(os.path.dirname(fname),
                                   os.path.basename(fname))
-                    self.Update() # Give feedback as files are loaded
+                    # Give feedback as files are loaded
+                    self.Update()
+
         self._ses_load = False
 
         if self.GetPageCount() == 0:
@@ -261,12 +258,12 @@ class EdPages(FNB.FlatNotebook):
         @postcondition: a new page with an untitled document is opened
 
         """
-        self.GetTopLevelParent().Freeze()
+        self.Freeze()
         self.pg_num += 1
-        self.control = ed_stc.EditraStc(self, wx.ID_ANY)
+        self.control = ed_editv.EdEditorView(self, wx.ID_ANY)
         self.control.SetEncoding(Profile_Get('ENCODING'))
         self.LOG("[ed_pages][evt] New Page Created ID: %d" % self.control.GetId())
-        self.AddPage(self.control, u"Untitled - %d" % self.pg_num)
+        self.AddPage(self.control, _("Untitled - %d") % self.pg_num)
         self.SetPageImage(self.GetSelection(), str(self.control.GetLangId()))
 
         # Set the control up the the preferred default lexer
@@ -274,7 +271,7 @@ class EdPages(FNB.FlatNotebook):
         ext_reg = syntax.ExtensionRegister()
         ext_lst = ext_reg.get(dlexer, ['txt', ])
         self.control.FindLexer(ext_lst[0])
-        self.GetTopLevelParent().Thaw()
+        self.Thaw()
 
     def OnCopyTabPath(self, evt):
         """Copy the path of the selected tab to the clipboard.
@@ -344,13 +341,13 @@ class EdPages(FNB.FlatNotebook):
         if self.GetPageCount():
             if self.control.GetModify() or self.control.GetLength() or \
                self.control.GetFileName() != u'':
-                control = ed_stc.EditraStc(self, wx.ID_ANY)
+                control = ed_editv.EdEditorView(self, wx.ID_ANY)
                 control.Hide()
             else:
                 new_pg = False
                 control = self.control
         else:
-            control = ed_stc.EditraStc(self, wx.ID_ANY)
+            control = ed_editv.EdEditorView(self, wx.ID_ANY)
             control.Hide()
 
         # Open file and get contents
@@ -409,14 +406,15 @@ class EdPages(FNB.FlatNotebook):
         self.control.EmptyUndoBuffer()
 
         if Profile_Get('SAVE_POS'):
-            self.control.GotoPos(self.DocMgr.GetPos(self.control.GetFileName()))
+            pos = self.DocMgr.GetPos(self.control.GetFileName())
+            self.control.GotoPos(pos)
+            self.control.ScrollToColumn(0)
 
         # Add the buffer to the notebook
         if new_pg:
             self.AddPage(self.control, filename)
 
-        self.frame.SetTitle("%s - file://%s" % (filename,
-                                                self.control.GetFileName()))
+        self.frame.SetTitle(self.control.GetTitleString())
         self.frame.AddFileToHistory(path2file)
         self.SetPageText(self.GetSelection(), filename)
         self.LOG("[ed_pages][evt] Opened Page: %s" % filename)
@@ -480,8 +478,7 @@ class EdPages(FNB.FlatNotebook):
 
         """
         pages = [self.GetPage(page) for page in xrange(self.GetPageCount())]
-        return [page for page in pages 
-                if getattr(page, '__name__', '') == "EditraTextCtrl"]
+        return [page for page in pages if page.GetName() == "EditraTextCtrl"]
 
     def HasFileOpen(self, fpath):
         """Checks if one of the currently active buffers has
@@ -559,17 +556,10 @@ class EdPages(FNB.FlatNotebook):
         @type evt: wx.IdleEvent
 
         """
-        if wx.GetApp().IsActive() and \
-           Profile_Get('CHECKMOD') and self.GetPageCount():
-            cfile = self.control.GetFileName()
-            lmod = util.GetFileModTime(cfile)
-            if self.control.GetModTime() and \
-               not lmod and not os.path.exists(cfile):
-                wx.CallAfter(PromptToReSave, self, cfile)
-            elif self.control.GetModTime() < lmod:
-                wx.CallAfter(AskToReload, self, cfile)
-            else:
-                return False
+        if wx.GetApp().IsActive() and self.GetPageCount():
+            page = self.GetCurrentPage()
+            if page is not None:
+                page.DoOnIdle()
 
     def OnLeftUp(self, evt):
         """Traps clicks sent to page close buttons and
@@ -618,12 +608,11 @@ class EdPages(FNB.FlatNotebook):
         window = self.GetPage(pg_num)
         window.SetFocus()
         self.control = window
-        fname = self.control.GetFileName()
 
         # Update Frame Title
-        if fname == "":
-            fname = self.GetPageText(pg_num)
-        self.frame.SetTitle("%s - file://%s" % (util.GetFileName(fname), fname))
+        self.frame.SetTitle(self.control.GetTitleString())
+
+        # Only post page changes when the change is not from the app exiting
         if not self.frame.IsExiting():
             ed_msg.PostMessage(ed_msg.EDMSG_UI_NB_CHANGED, (self, pg_num))
 
@@ -637,9 +626,11 @@ class EdPages(FNB.FlatNotebook):
         self.ChangePage(cpage)
         evt.Skip()
         self.LOG("[ed_pages][evt] Page Changed to %d" % cpage)
-        self.LOG("[ed_pages][info] It has file named: %s" % \
-                 self.control.GetFileName())
-        self.control.PostPositionEvent()
+        
+        # Call the tab specific selection handler
+        page = self.GetCurrentPage()
+        page.DoTabSelected()
+
         self.EnsureVisible(cpage)
 
     def OnPageClosing(self, evt):
@@ -649,9 +640,12 @@ class EdPages(FNB.FlatNotebook):
 
         """
         self.LOG("[ed_pages][evt] Closing Page: #%d" % self.GetSelection())
+
+        # Call the tab specific close handler
         page = self.GetCurrentPage()
-        if len(page.GetFileName()) > 1:
-            self.DocMgr.AddRecord([page.GetFileName(), page.GetCurrentPos()])
+        if page is not None:
+            page.DoTabClosing()
+
         evt.Skip()
         ed_msg.PostMessage(ed_msg.EDMSG_UI_NB_CLOSING,
                            (self, self.GetSelection()))
@@ -681,29 +675,26 @@ class EdPages(FNB.FlatNotebook):
 
     def ClosePage(self):
         """Closes Currently Selected Page
-        @postcondition: currently selected page is closed
+        @return: bool
 
         """
+        frame = self.GetTopLevelParent()
+        frame.Freeze()
         self.GoCurrentPage()
+        page = self.GetCurrentPage()
         pg_num = self.GetSelection()
-        result = wx.ID_OK
+        result = True
 
-        if self.control.GetModify():
-            result = self.frame.ModifySave()
-            if result != wx.ID_CANCEL:
-                self.DeletePage(pg_num)
-                self.GoCurrentPage()
-            else:
-                pass
-        else:
+        if page.CanCloseTab():
             self.DeletePage(pg_num)
             self.GoCurrentPage()
+        else:
+            return False
 
-        # TODO this causes some flashing
-        frame = self.GetTopLevelParent()
         if not self.GetPageCount() and \
            hasattr(frame, 'IsExiting') and not frame.IsExiting():
             self.NewPage()
+        frame.Thaw()
         return result
 
     def SetPageImage(self, pg_num, lang_id):
@@ -715,6 +706,7 @@ class EdPages(FNB.FlatNotebook):
         @param lang_id: language id of file type to get mime image for
 
         """
+        # Only set icons when enabled in preferences
         if not Profile_Get('TABICONS'):
             return
 
@@ -735,10 +727,12 @@ class EdPages(FNB.FlatNotebook):
         @postcondition: all images in control are updated
 
         """
+        # If icons preference has been disabled then clear all icons
         if not Profile_Get('TABICONS'):
             for page in xrange(self.GetPageCount()):
                 FNB.FlatNotebook.SetPageImage(self, page, -1)
         else:
+            # Reload the image list with new icons from the ArtProvider
             imglst = self.GetImageList()
             for lang, index in self._index.iteritems():
                 bmp = wx.ArtProvider.GetBitmap(str(lang), wx.ART_MENU)
@@ -780,7 +774,7 @@ class EdPages(FNB.FlatNotebook):
                 # Only Update if the text has changed
                 if title != FNB.FlatNotebook.GetPageText(self, pg_num):
                     self.SetPageText(pg_num, title)
-                    ftitle = u"%s - file://%s" % (title, self.control.GetFileName())
+                    ftitle = self.control.GetTitleString()
                     self.frame.SetTitle(ftitle)
             else:
                 # A background page has changed
@@ -810,55 +804,3 @@ class EdPages(FNB.FlatNotebook):
                 control.Configure()
 
 #---- End Function Definitions ----#
-
-#-----------------------------------------------------------------------------#
-
-#---- Utility Function Definitions ----#
-def PromptToReSave(win, cfile):
-    """Show a dialog prompting to resave the current file
-    @param win: Window to prompt dialog on top of
-    @param cfile: the file in question
-
-    """
-    mdlg = wx.MessageDialog(win.frame,
-                            _("%s has been deleted since its "
-                              "last save point.\n\nWould you "
-                              "like to save it again?") % cfile,
-                            _("Resave File?"),
-                            wx.YES_NO | wx.ICON_INFORMATION)
-    mdlg.CenterOnParent()
-    result = mdlg.ShowModal()
-    mdlg.Destroy()
-    if result == wx.ID_YES:
-        result = win.control.SaveFile(cfile)
-    else:
-        win.control.SetModTime(0)
-
-def AskToReload(win, cfile):
-    """Show a dialog asking if the file should be reloaded
-    @param win: Window to prompt dialog on top of
-    @param cfile: the file to prompt for a reload of
-
-    """
-    mdlg = wx.MessageDialog(win.frame,
-                            _("%s has been modified by another "
-                              "application.\n\nWould you like "
-                              "to Reload it?") % cfile,
-                              _("Reload File?"),
-                              wx.YES_NO | wx.ICON_INFORMATION)
-    mdlg.CenterOnParent()
-    result = mdlg.ShowModal()
-    mdlg.Destroy()
-    if result == wx.ID_YES:
-        ret, rmsg = win.control.ReloadFile()
-        if not ret:
-            errmap = dict(filename=cfile, errmsg=rmsg)
-            mdlg = wx.MessageDialog(win.frame,
-                                    _("Failed to reload %(filename)s:\n"
-                                      "Error: %(errmsg)s") % errmap,
-                                    _("Error"),
-                                    wx.OK | wx.ICON_ERROR)
-            mdlg.ShowModal()
-            mdlg.Destroy()
-    else:
-        win.control.SetModTime(util.GetFileModTime(cfile))
