@@ -16,8 +16,8 @@ highlight text in a StyledTextCtrl.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_search.py 56009 2008-10-01 13:26:04Z CJP $"
-__revision__ = "$Revision: 56009 $"
+__svnid__ = "$Id: ed_search.py 56608 2008-10-31 02:24:14Z CJP $"
+__revision__ = "$Revision: 56608 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -25,6 +25,7 @@ import os
 import sys
 import re
 import types
+from StringIO import StringIO
 import wx
 
 # Local imports
@@ -34,7 +35,7 @@ import ed_msg
 import plugin
 import iface
 from util import FileTypeChecker
-from profiler import Profile_Get
+from profiler import Profile_Get, Profile_Set
 import eclib.ctrlbox as ctrlbox
 import eclib.outbuff as outbuff
 import eclib.platebtn as platebtn
@@ -59,7 +60,7 @@ class SearchController:
         self._parent   = owner
         self._stc      = getstc
         self._finddlg  = None
-        self._posinfo  = dict(scroll=0, start=0, found=0)
+        self._posinfo  = dict(scroll=0, start=0, found=0, ldir=None)
         self._data     = wx.FindReplaceData(finddlg.AFR_RECURSIVE)
         self._li_choices = list()
         self._li_sel   = 0
@@ -182,18 +183,39 @@ class SearchController:
         data.SetFindString(evt.GetFindString())
 
         # Create the search engine
-        # XXX: may be inefficent to copy whole buffer each time for files
-        #      that are large.
         isdown = not evt.IsUp()
         engine = SearchEngine(data.GetFindString(), evt.IsRegEx(),
                               isdown, evt.IsMatchCase(), evt.IsWholeWord())
+
+        # Check if expression was valid or not
+        if engine.GetQueryObject() is None:
+            wx.MessageBox(_("Invalid expression \"%s\"") % engine.GetQuery(),
+                          _("Regex Compile Error"),
+                          style=wx.OK|wx.CENTER|wx.ICON_ERROR)
+            return
+
+        # XXX: may be inefficent to copy whole buffer each time for files
+        #      that are large.
         engine.SetSearchPool(stc.GetTextRaw())
 
+        # Check if the direction changed
+        ldir = self._posinfo['ldir']
+        if isdown:
+            self._posinfo['ldir'] = 'down'
+        else:
+            self._posinfo['ldir'] = 'up'
+
         # Get the search start position
         if evt.GetEventType() == finddlg.edEVT_FIND:
             spos = self._posinfo['found']
         else:
             spos = stc.GetCurrentPos()
+            if ldir != self._posinfo['ldir']:
+                start, end = stc.GetSelection()
+                if ldir == 'down':
+                    spos = start
+                else:
+                    spos = end
 
         # Do the find
         match = engine.Find(spos)
@@ -205,6 +227,7 @@ class SearchController:
                 stc.SetSelection(end, start)
             stc.EnsureCaretVisible()
             self._posinfo['found'] = start
+
             ed_msg.PostMessage(ed_msg.EDMSG_UI_SB_TXT,
                                (ed_glob.SB_INFO, u""))
         else:
@@ -220,7 +243,9 @@ class SearchController:
                                   _("Search wrapped to bottom")))
 
             if match is not None:
-                self._posinfo['found'] = match[0]
+                start, end = match
+                self._posinfo['found'] = start
+
                 match = list(match)
                 if not isdown:
                     match.reverse()
@@ -242,9 +267,12 @@ class SearchController:
         if not query:
             return
 
+        # Create a new search engine object
         engine = SearchEngine(query, evt.IsRegEx(), True,
                               evt.IsMatchCase(), evt.IsWholeWord())
 
+        # Send the search function over to any interested parties that wish
+        # to process the results.
         if smode == finddlg.LOCATION_CURRENT_DOC:
             stc = self._stc()
             fname = stc.GetFileName()
@@ -253,7 +281,7 @@ class SearchController:
                                    (engine.SearchInFile, [fname,], dict()))
             else:
                 engine.SetSearchPool(stc.GetTextRaw())
-                ed_msg.PostMessage(ed_msg.EDMSG_START_SEARCH, (engine.FindAll))
+                ed_msg.PostMessage(ed_msg.EDMSG_START_SEARCH, (engine.FindAllLines,))
         elif smode == finddlg.LOCATION_OPEN_DOCS:
             files = [fname.GetFileName()
                      for fname in self._parent.GetTextControls()]
@@ -275,6 +303,16 @@ class SearchController:
             self._li_choices = self._finddlg.GetLookinChoices()
             self._li_sel = self._finddlg.GetLookinSelection()
 
+            # Store in profile. Only save most recent 5 in history
+            if len(self._li_choices) > 5:
+                choices = self._li_choices[-5:]
+            else:
+                choices = self._li_choices
+            choices.reverse()
+
+            # Save the most recent choices of search locations
+            Profile_Set('SEARCH_LOC', choices)
+
             # Destroy it
             self._finddlg.Destroy()
 
@@ -374,6 +412,14 @@ class SearchController:
             stc.ReplaceTarget(rstring)
         stc.EndUndoAction()
 
+    def SetLookinChoices(self, choices):
+        """Set the list of locations to use for the recent search
+        locations.
+        @param choices: list of strings
+
+        """
+        self._li_choices = choices
+
     def SetQueryString(self, query):
         """Sets the search query value
         @param query: string to search for
@@ -428,7 +474,7 @@ class SearchEngine:
         @postcondition: the engines regular expression is created
 
         """
-        tmp = str(self._query)
+        tmp = self._query
         if not self._isregex:
             tmp = EscapeRegEx(tmp)
 
@@ -442,8 +488,11 @@ class SearchEngine:
 
         if self._unicode:
             flags |= re.UNICODE
-            
-        self._regex = re.compile(tmp, flags)
+
+        try:
+            self._regex = re.compile(tmp, flags)
+        except:
+            self._regex = None
 
     def Find(self, spos=0):
         """Find the next match based on the state of the search engine
@@ -452,6 +501,9 @@ class SearchEngine:
         @prerequisite: L{SetSearchPool} has been called to set search string
 
         """
+        if self._regex is None:
+            return None
+
         if self._next:
             return self.FindNext(spos)
         else:
@@ -464,11 +516,33 @@ class SearchEngine:
         @return: list of tuples [(start1, end1), (start2, end2), ]
 
         """
-        matches = [match for match in re.finditer(self._regex, self._pool)]
+        if self._regex is None:
+            return list()
+
+        matches = [ match for match in re.finditer(self._regex, self._pool) ]
         if len(matches):
             matches = [match.span() for match in matches]
             return matches
-        return None
+        return list()
+
+    def FindAllLines(self):
+        """Find all the matches in the current context
+        @return: list of strings
+
+        """
+        rlist = list()
+        if self._regex is None:
+            return rlist
+
+        flag = 0
+        if not self._matchcase:
+            flag = re.IGNORECASE
+
+        for lnum, line in enumerate(StringIO(self._pool)):
+            if self._regex.search(line, flag) is not None:
+                rlist.append(FormatResult(_("Untitled"), lnum, line))
+
+        return rlist
 
     def FindNext(self, spos=0):
         """Find the next match of the query starting at spos
@@ -478,8 +552,11 @@ class SearchEngine:
                        search in.
 
         """
+        if self._regex is None:
+            return None
+
         if spos < len(self._pool):
-            match = re.search(self._regex, self._pool[spos:])
+            match = self._regex.search(self._pool[spos:])
             if match is not None:
                 return match.span()
         return None
@@ -491,6 +568,9 @@ class SearchEngine:
         @return: tuple (match start pos, match end pos)
 
         """
+        if self._regex is None:
+            return None
+
         if spos+1 < len(self._pool):
             matches = [match for match in re.finditer(self._regex, self._pool[:spos])]
             if len(matches):
@@ -498,6 +578,20 @@ class SearchEngine:
                 return (lmatch.start(), lmatch.end())
         return None
 
+    def GetOptionsString(self):
+        """Get a string describing the search engines options"""
+        rstring = u"\"%s\" [ " % self._query
+        for desc, attr in ((_("regex: %s"), self._isregex), 
+                          (_("match case: %s"), self._matchcase),
+                          (_("whole word: %s"), self._wholeword)):
+            if attr:
+                rstring += (desc % u"on; ")
+            else:
+                rstring += (desc % u"off; ")
+        rstring += u"]"
+
+        return rstring
+
     def GetQuery(self):
         """Get the raw query string used by the search engine
         @return: string
@@ -505,6 +599,14 @@ class SearchEngine:
         """
         return self._query
 
+    def GetQueryObject(self):
+        """Get the regex object used for the search. Will return None if
+        there was an error in creating the object.
+        @return: pattern object
+
+        """
+        return self._regex
+
     def IsMatchCase(self):
         """Is the engine set to a case sensitive search
         @return: bool
@@ -529,6 +631,7 @@ class SearchEngine:
     def SearchInBuffer(self, sbuffer):
         """Search in the buffer
         @param sbuffer: buffer like object
+        @todo: implement
 
         """
         
@@ -539,10 +642,17 @@ class SearchEngine:
         @keyword recursive: search recursivly
 
         """
+        if self._regex is None:
+            return
+
+        # Get all files in the directories
         paths = [os.path.join(directory, fname)
                 for fname in os.listdir(directory) if not fname.startswith('.')]
+
+        # Begin searching in the paths
         for path in paths:
             if recursive and os.path.isdir(path):
+                # Recursive call to decend into directories
                 for match in self.SearchInDirectory(path, recursive):
                     yield match
             else:
@@ -557,6 +667,9 @@ class SearchEngine:
         @todo: unicode handling
 
         """
+        if self._regex is None:
+            return
+
         fchecker = FileTypeChecker()
         if fchecker.IsReadableText(fname):
             try:
@@ -572,7 +685,7 @@ class SearchEngine:
                 flag = re.IGNORECASE
 
             for lnum, line in enumerate(fobj):
-                if re.search(self._regex, line, flag) is not None:
+                if self._regex.search(line, flag) is not None:
                     yield FormatResult(fname, lnum, line)
             fobj.close()
         return
@@ -582,6 +695,9 @@ class SearchEngine:
         @param flist: list of file names
 
         """
+        if self._regex is None:
+            return
+
         for fname in flist:
             for match in self.SearchInFile(fname):
                 yield match
@@ -715,7 +831,12 @@ class EdSearchCtrl(wx.SearchCtrl):
         @param flag: flag to clear from search data
 
         """
-        self._flags ^= flag
+        data = self.GetSearchData()
+        if data is not None:
+            c_flags = data.GetFlags()
+            c_flags ^= flag
+            self._flags = c_flags
+            data.SetFlags(self._flags)
 
     def DoSearch(self, next=True):
         """Do the search and move the selection
@@ -808,10 +929,22 @@ class EdSearchCtrl(wx.SearchCtrl):
 
         """
         data = self.GetSearchData()
-        if data != None:
+        if data is not None:
             return bool(finddlg.AFR_MATCHCASE & data.GetFlags())
         return False
 
+    def IsRegEx(self):
+        """Returns True if the search control is set to search
+        in regular expression mode.
+        @return: whether search is using regular expressions or not
+        @rtype: boolean
+
+        """
+        data = self.GetSearchData()
+        if data is not None:
+            return bool(finddlg.AFR_REGEX & data.GetFlags())
+        return False
+
     def IsSearchPrevious(self):
         """Returns True if the search control is set to search
         in Previous mode.
@@ -820,7 +953,7 @@ class EdSearchCtrl(wx.SearchCtrl):
 
         """
         data = self.GetSearchData()
-        if data != None:
+        if data is not None:
             return bool(finddlg.AFR_UP & data.GetFlags())
         return False
 
@@ -832,7 +965,7 @@ class EdSearchCtrl(wx.SearchCtrl):
 
         """
         data = self.GetSearchData()
-        if data != None:
+        if data is not None:
             return bool(finddlg.AFR_WHOLEWORD & data.GetFlags())
         return False
 
@@ -851,7 +984,12 @@ class EdSearchCtrl(wx.SearchCtrl):
         @param flags: search flag to add
 
         """
-        self._flags |= flags
+        data = self.GetSearchData()
+        if data is not None:
+            c_flags = data.GetFlags()
+            c_flags |= flags
+            self._flags = c_flags
+            data.SetFlags(self._flags)
 
     #---- End Functions ----#
 
@@ -872,7 +1010,7 @@ class EdSearchCtrl(wx.SearchCtrl):
             self.GetParent().Hide()
             return
         elif e_key == wx.WXK_SHIFT:
-            self.SetSearchFlag(wx.FR_DOWN)
+            self.ClearSearchFlag(finddlg.AFR_UP)
             return
         else:
             pass
@@ -883,7 +1021,10 @@ class EdSearchCtrl(wx.SearchCtrl):
         # Dont do search for navigation keys
         if tmp == wx.EmptyString or evt.CmdDown() or \
            e_key in [wx.WXK_COMMAND, wx.WXK_LEFT, wx.WXK_RIGHT,
-                     wx.WXK_UP, wx.WXK_DOWN]:
+                     wx.WXK_UP, wx.WXK_DOWN, wx.WXK_F1, wx.WXK_F2,
+                     wx.WXK_F3, wx.WXK_F4, wx.WXK_F5, wx.WXK_F6,
+                     wx.WXK_F7, wx.WXK_F8, wx.WXK_F9, wx.WXK_F10,
+                     wx.WXK_F11, wx.WXK_F12]:
             return
 
         if e_key == wx.WXK_RETURN or e_key == wx.WXK_F3:
@@ -892,7 +1033,10 @@ class EdSearchCtrl(wx.SearchCtrl):
             else:
                 self.DoSearch(next=True)
         else:
-            self.DoSearch(next=True)
+            # Don't do incremental searches when the RegEx flag is set in order
+            # to avoid errors in compiling the expression
+            if not self.IsRegEx():
+                self.DoSearch(next=True)
 
     def OnCancel(self, evt):
         """Cancels the Search Query
@@ -1000,8 +1144,10 @@ class EdFindResults(plugin.Plugin):
                 screen = shelf_nb.GetCurrentPage()
             data = msg.GetData()
             if len(data) > 1:
+                # Doing a file search operation
                 screen.StartSearch(data[0], *data[1], **data[2])
             else:
+                # Doing a buffer find operation (in memory)
                 screen.StartSearch(data[0])
 
 #-----------------------------------------------------------------------------#
@@ -1016,6 +1162,7 @@ class SearchResultScreen(ctrlbox.ControlBox):
         ctrlbox.ControlBox.__init__(self, parent)
 
         # Attributes
+        self._meth = None
         self._job = None
         self._list = SearchResultList(self)
         self._cancelb = None
@@ -1080,6 +1227,8 @@ class SearchResultScreen(ctrlbox.ControlBox):
 
         """
         start = u">>> %s" % _("Search Started")
+        if self._meth is not None:
+            start += (u": " + self._meth.im_self.GetOptionsString())
         self._list.SetStartEndText(start + os.linesep)
         self._list.Start(250)
 
@@ -1088,8 +1237,12 @@ class SearchResultScreen(ctrlbox.ControlBox):
         @param evt: UpdateBufferEvent
 
         """
+        self._meth = None
+
+        # Stop the timer
         self._list.Stop()
         self._cancelb.Disable()
+
         # Update statusbar to show search is complete
         ed_msg.PostMessage(ed_msg.EDMSG_UI_SB_TXT,
                            (ed_glob.SB_INFO, _("Search complete")))
@@ -1127,6 +1280,8 @@ class SearchResultScreen(ctrlbox.ControlBox):
         @param searchmeth: callable
 
         """
+        self._meth = searchmeth
+
         if self._job is not None:
             self._job.Cancel()
 
@@ -1165,11 +1320,13 @@ class SearchResultList(outbuff.OutputBuffer):
 
         """
         if isinstance(value, basestring):
+            # Regular search result
             outbuff.OutputBuffer.AppendUpdate(self, value)
         else:
+            # Search in a new file has started
             ed_msg.PostMessage(ed_msg.EDMSG_UI_SB_TXT,
                                (ed_glob.SB_INFO,
-                                _("Searching in : %s") % value[1]))
+                               _("Searching in : %s") % value[1]))
 
     def ApplyStyles(self, start, txt):
         """Set a hotspot for each search result
