@@ -18,14 +18,13 @@ specific options such as commenting code.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_stc.py 55996 2008-10-01 03:37:14Z CJP $"
-__revision__ = "$Revision: 55996 $"
+__svnid__ = "$Id: ed_stc.py 56649 2008-11-02 17:19:34Z CJP $"
+__revision__ = "$Revision: 56649 $"
 
 #-------------------------------------------------------------------------#
 # Imports
 
 import os
-import re
 import wx, wx.stc
 
 # Local Imports
@@ -51,8 +50,12 @@ NUM_MARGIN  = 1
 FOLD_MARGIN = 2
 
 SPACECHARS = " \t\r\n"
-NONSPACE = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ" + \
-           "0123456789_./\?[]{}<>!@#$%^&*():=-+\"';,"
+NONSPACE = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_"
+OPERATORS = "./\?[]{}<>!@#$%^&*():=-+\"';,"
+
+ALT_SHIFT = wx.stc.STC_SCMOD_ALT|wx.stc.STC_SCMOD_SHIFT
+CTRL_SHIFT = wx.stc.STC_SCMOD_CTRL|wx.stc.STC_SCMOD_SHIFT
+
 #-------------------------------------------------------------------------#
 
 class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
@@ -136,6 +139,11 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.Configure()
         self.UpdateBaseStyles()
 
+        # Set Mac specific keybindings
+        if wx.Platform == '__WXMAC__':
+            for keys in _GetMacKeyBindings():
+                self.CmdKeyAssign(*keys)
+
         # Other Settings
         self._menu = MakeMenu()
         self.UsePopUp(False)
@@ -200,6 +208,27 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 #         code = compile(code_txt, self.__module__, 'exec')
 #         exec code in self.__dict__ # Inject new code into this namespace
 
+    def _MacHandleKey(self, k_code, shift_down, alt_down, ctrl_down, cmd_down):
+        """Handler for mac specific actions"""
+        if (k_code == wx.WXK_BACK and shift_down) and \
+           not (alt_down or ctrl_down or cmd_down):
+            self.DeleteForward()
+        elif cmd_down and True not in (alt_down, ctrl_down):
+            line = self.GetCurrentLine()
+            if k_code == wx.WXK_RIGHT:
+                pos = self.GetLineStartPosition(line)
+                txt = self.GetLine(line)
+                diff = len(txt.rstrip())
+                self.GotoPos(pos + diff)
+            elif k_code == wx.WXK_LEFT:
+                self.GotoIndentPos(line)
+            else:
+                return False
+        else:
+            return False
+
+        return True
+
     #---- Public Member Functions ----#
     def PlayMacro(self):
         """Send the list of built up macro messages to the editor
@@ -626,6 +655,15 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.SetFoldMarginHiColour(True, fore)
         self.SetFoldMarginColour(True, fore)
 
+    def DeleteForward(self):
+        """Delete the selection, or if there is no selection, then
+        delete the character to the right of the cursor.
+
+        """
+        if self.GetSelectionStart() == self.GetSelectionEnd():
+            self.SetCurrentPos(self.GetCurrentPos() + 1)
+        self.DeleteBack()
+
     def FindTagById(self, style_id):
         """Find the style tag that is associated with the given
         Id. If not found it returns an empty string.
@@ -710,12 +748,19 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         """
         k_code = evt.GetKeyCode()
-        if self.key_handler.PreProcessKey(k_code, evt.ControlDown(),
-                                          evt.CmdDown(), evt.ShiftDown(),
-                                          evt.AltDown()):
+        shift_down = evt.ShiftDown()
+        alt_down = evt.AltDown()
+        ctrl_down = evt.ControlDown()
+        cmd_down = evt.CmdDown()
+
+        if self.key_handler.PreProcessKey(k_code, ctrl_down,
+                                          cmd_down, shift_down, alt_down):
             return                
 
-        if k_code == wx.WXK_RETURN:
+        if wx.Platform == '__WXMAC__' and \
+           self._MacHandleKey(k_code, shift_down, alt_down, ctrl_down, cmd_down):
+            pass
+        elif k_code == wx.WXK_RETURN:
 
             if self._config['autoindent'] and not self.AutoCompActive():
                 if self.GetSelectedText():
@@ -930,7 +975,13 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         # number width over fills the area.
         lines = self.GetLineCount()
         mwidth = self.GetTextExtent(str(lines))[0]
-        self.SetMarginWidth(NUM_MARGIN, max(30, mwidth + 8))
+
+        if wx.Platform == '__WXMAC__':
+            adj = 2
+        else:
+            adj = 8
+
+        self.SetMarginWidth(NUM_MARGIN, max(15, mwidth + adj))
 
         wx.PostEvent(self.GetParent(), evt)
 
@@ -1527,28 +1578,50 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @postcondition: all trailing whitespace is removed from document
 
         """
-        txt = u''
         cpos = self.GetCurrentPos()
         cline = self.GetCurrentLine()
-        for line in xrange(self.GetLineCount()):
+        cline_len = len(self.GetLine(cline))
+        epos = cline_len - (self.GetLineEndPosition(cline) - cpos)
+
+        # Begin stripping trailing whitespace
+        self.BeginUndoAction()
+        for line in xrange(self.GetLineCount() + 1):
+            eol = u''
             tmp = self.GetLine(line)
-            if len(tmp):
-                eol = tmp[-1]
+            tlen = len(tmp)
+            if tlen:
+                if "\r\n" in tmp:
+                    eol = "\r\n"
+                elif "\n" in tmp:
+                    eol = "\n"
+                else:
+                    eol = tmp[-1]
+
                 if not eol.isspace():
+                    continue
+                elif eol in u' \t':
                     eol = u''
             else:
-                eol = u''
-            if line == cline:
-                npos = cpos - (abs(len(self.GetTextRange(0, \
-                                       self.GetLineEndPosition(cline-1))) - \
-                                   len(txt)) + 1)
-                next = cpos - 1
-                while self.GetTextRange(next, cpos).isspace() and next > 0:
-                    next = next - 1
-                cpos = npos - ((cpos - next) - 1)
-            txt = txt + tmp.rstrip() + eol
-        self.SetText(txt)
-        self.GotoPos(cpos)
+                continue
+
+            # Strip the extra whitespace from the line
+            end = self.GetLineEndPosition(line) + len(eol)
+            start = max(end - tlen, 0)
+            self.SetTargetStart(start)
+            self.SetTargetEnd(end)
+            self.ReplaceTarget(tmp.rstrip() + eol)
+        self.EndUndoAction()
+
+        # Restore carat position
+        cline_len = len(self.GetLine(cline))
+        end = self.GetLineEndPosition(cline)
+        if epos >= cline_len:
+            epos = end
+        else:
+            start = max(end - cline_len, 0)
+            epos += start
+
+        self.GotoPos(epos)
 
     def FoldingOnOff(self, switch=None):
         """Turn code folding on and off
@@ -1833,6 +1906,10 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             self.file.SetPath(path)
             self.LOG("[ed_stc][info] Writing file %s, with encoding %s" % \
                      (path, self.file.GetEncoding()))
+
+            if _PGET('AUTO_TRIM_WS', 'bool', False):
+                self.TrimWhitespace()
+
             self.file.Write(self.GetText())
         except Exception, msg:
             result = False
@@ -1991,6 +2068,9 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         kwlist = self._code['keywords'].split()    # Split into a list of words
         kwlist = list(set(kwlist))                 # Uniqueify the list
         kwlist.sort()                              # Sort into alphbetical order
+        # Can't have ? in scintilla autocomp list unless specifying an image
+        if '?' in kwlist:
+            kwlist.remove('?')
         self._code['keywords'] = " ".join(kwlist)  # Put back into a string
         return True
 
@@ -2143,3 +2223,54 @@ def MakeMenu():
     menu.AppendSeparator()
     menu.Append(ed_glob.ID_SELECTALL, _("Select All"))
     return menu
+
+def _GetMacKeyBindings():
+    """Returns a list of 3-element tuples defining the standard key
+    bindings for Mac text editors -- i.e., the behavior of option-arrow,
+    shift-delete, and so on.  Each tuple consists of:
+        (key code, modifier keys, STC action)
+    """
+    # A good reference for these: http://www.yellowbrain.com/stc/keymap.html
+    return [
+            # Move/select/delete by word
+            (wx.stc.STC_KEY_LEFT, wx.stc.STC_SCMOD_ALT, 
+             wx.stc.STC_CMD_WORDLEFT),
+            (wx.stc.STC_KEY_RIGHT, wx.stc.STC_SCMOD_ALT, 
+             wx.stc.STC_CMD_WORDRIGHT),
+            (wx.stc.STC_KEY_LEFT, ALT_SHIFT, wx.stc.STC_CMD_WORDLEFTEXTEND),
+            (wx.stc.STC_KEY_RIGHT, ALT_SHIFT, wx.stc.STC_CMD_WORDRIGHTEXTEND),
+            (wx.stc.STC_KEY_BACK, wx.stc.STC_SCMOD_ALT,
+             wx.stc.STC_CMD_DELWORDLEFT),
+            (wx.stc.STC_KEY_DELETE, wx.stc.STC_SCMOD_ALT,
+             wx.stc.STC_CMD_DELWORDRIGHT),
+            (wx.stc.STC_KEY_BACK, ALT_SHIFT, wx.stc.STC_CMD_DELWORDRIGHT),
+            (wx.stc.STC_KEY_DELETE, ALT_SHIFT, wx.stc.STC_CMD_DELWORDLEFT),
+            
+            # Move/select/delete by line
+            (wx.stc.STC_KEY_LEFT, wx.stc.STC_SCMOD_CTRL,
+             wx.stc.STC_CMD_VCHOME),
+            (wx.stc.STC_KEY_LEFT, CTRL_SHIFT, wx.stc.STC_CMD_VCHOMEEXTEND),
+            (wx.stc.STC_KEY_RIGHT, wx.stc.STC_SCMOD_CTRL,
+             wx.stc.STC_CMD_LINEEND),
+            (wx.stc.STC_KEY_RIGHT, CTRL_SHIFT, wx.stc.STC_CMD_LINEENDEXTEND),
+            (wx.stc.STC_KEY_BACK, wx.stc.STC_SCMOD_CTRL,
+             wx.stc.STC_CMD_DELLINELEFT),
+            (wx.stc.STC_KEY_DELETE, wx.stc.STC_SCMOD_CTRL,
+             wx.stc.STC_CMD_DELLINERIGHT),
+            (wx.stc.STC_KEY_BACK, CTRL_SHIFT, wx.stc.STC_CMD_DELLINERIGHT),
+            (wx.stc.STC_KEY_DELETE, CTRL_SHIFT, wx.stc.STC_CMD_DELLINELEFT),
+            
+            # By-character deletion behavior
+            (wx.stc.STC_KEY_BACK, wx.stc.STC_SCMOD_NORM,
+             wx.stc.STC_CMD_DELETEBACK),
+            (wx.stc.STC_KEY_DELETE, wx.stc.STC_SCMOD_SHIFT,
+             wx.stc.STC_CMD_DELETEBACK),
+
+            # NOTE: The following two are a special case, since Scintilla 
+            # doesn't have a forward-delete action.  So here we just cancel any
+            # tip our auto-completion display, and then implement forward 
+            # delete in OnKeyDown.
+            #(wx.stc.STC_KEY_DELETE, 0, wx.stc.STC_CMD_CANCEL),
+            (wx.stc.STC_KEY_BACK, wx.stc.STC_SCMOD_SHIFT,
+             wx.stc.STC_CMD_CANCEL),
+            ]
