@@ -20,16 +20,18 @@ happen during run time.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: profiler.py 55000 2008-08-07 00:03:20Z CJP $"
-__revision__ = "$Revision: 55000 $"
+__svnid__ = "$Id: profiler.py 56361 2008-10-16 15:41:15Z CJP $"
+__revision__ = "$Revision: 56361 $"
 
 #--------------------------------------------------------------------------#
-# Dependancies
+# Imports
 import os
 import sys
 import cPickle
 import wx
-from ed_glob import CONFIG, PROG_NAME, VERSION
+
+# Editra Imports
+from ed_glob import CONFIG, PROG_NAME, VERSION, PRINT_BLACK_WHITE
 import util
 import dev_tool
 
@@ -42,6 +44,7 @@ _DEFAULTS = {
            'APPSPLASH'  : True,             # Show splash at startup
            'AUTO_COMP'  : True,             # Use Auto-comp if available
            'AUTO_INDENT': True,             # Use Auto Indent
+           'AUTO_TRIM_WS' : False,          # Trim whitespace on save
            'BRACKETHL'  : True,             # Use bracket highlighting
            'BSUNINDENT' : True,             # Backspace Unindents
            'CHECKMOD'   : True,             # Auto check file for file mod
@@ -51,6 +54,7 @@ _DEFAULTS = {
            'DEFAULT'    : False,            # No longer used I believe
            'DEFAULT_VIEW' : 'Automatic',    # Default Perspective
            'EDGE'       : 80,               # Edge guide column
+           'ENCODING'   : None,             # Prefered text encoding
            'EOL'        : 'Unix (\\n)',     # EOL mode
            'FHIST'      : list(),           # List of history files
            'FHIST_LVL'  : 9,                # Filehistory length (9 is max)
@@ -68,11 +72,12 @@ _DEFAULTS = {
            'MODE'       : 'CODE',           # Overall editor mode
            'MYPROFILE'  : 'default.ppb',    # Path to profile file
            'OPEN_NW'    : False,            # Open files in new windows
-           'PRINT_MODE' : 'BLACK/WHITE',    # Printer rendering mode
+           'PRINT_MODE' : PRINT_BLACK_WHITE,# Printer rendering mode
            'PROXY_SETTINGS' : dict(),       # Proxy Server Settings
            'REPORTER'   : True,             # Error Reporter is Active
            'SAVE_POS'   : True,             # Remember Carat positions
            'SAVE_SESSION' : False,          # Load previous session on startup
+           'SEARCH_LOC' : list(),           # Recent Search Locations
            'SESSION_KEY' : '',              # Ipc Session Server Key
            'SET_WPOS'   : True,             # Remember window position
            'SET_WSIZE'  : True,             # Remember mainwindow size on exit
@@ -371,8 +376,13 @@ def GetLoader():
            should be.
 
     """
-    loader = os.path.join(wx.GetHomeDir(), u"." + PROG_NAME,
-                          u"profiles", u".loader2")
+    cbase = CONFIG['CONFIG_BASE']
+    if cbase is None:
+        loader = os.path.join(wx.GetHomeDir(), u"." + PROG_NAME,
+                              u"profiles", u".loader2")
+    else:
+        loader = os.path.join(cbase, u"profiles", u".loader2")
+
     return loader
 
 def GetProfileStr():
