@@ -19,8 +19,8 @@ LANGUAGE: Python
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: synextreg.py 54489 2008-07-05 05:48:54Z CJP $"
-__revision__ = "$Revision: 54489 $"
+__svnid__ = "$Id: synextreg.py 55738 2008-09-19 16:40:49Z CJP $"
+__revision__ = "$Revision: 55738 $"
 
 #-----------------------------------------------------------------------------#
 import os
@@ -113,7 +113,7 @@ LANG_ESS = u'Editra Style Sheet'
 
 # Use LEX_EIFFEL
 ID_LANG_EIFFEL = _NewId()
-LANG_EIFFEL = u"Eiffel"
+LANG_EIFFEL = u'Eiffel'
 
 # Use LEX_ERLANG
 ID_LANG_ERLANG = _NewId()
@@ -167,6 +167,8 @@ ID_LANG_LISP = _NewId()
 LANG_LISP = u'Lisp'
 ID_LANG_SCHEME = _NewId()
 LANG_SCHEME = u'Scheme'
+ID_LANG_NEWLISP = _NewId()
+LANG_NEWLISP = u'newLISP'
 
 # Use LEX_LOUT
 ID_LANG_LOUT = _NewId()
@@ -204,7 +206,7 @@ LANG_PYTHON = u'Python'
 
 # Use LEX_MATLAB
 ID_LANG_MATLAB = _NewId()
-LANG_MATLAB = u"Matlab"
+LANG_MATLAB = u'Matlab'
 
 # Use LEX_RUBY
 ID_LANG_RUBY = _NewId()
@@ -267,6 +269,10 @@ ID_LANG_DJANGO = _NewId()
 LANG_DJANGO = u'Django'
 ID_LANG_MAKO = _NewId()
 LANG_MAKO = u'Mako'
+ID_LANG_R = _NewId()
+LANG_R = u'R'
+ID_LANG_S = _NewId()
+LANG_S = u'S'
 
 #---- End Language Identifier Keys ----#
 
@@ -308,7 +314,8 @@ EXT_MAP = {
            'kix'                : LANG_KIX,
            'ksh'                : LANG_KSH,
            'aux tex sty'        : LANG_LATEX,
-           'cl lisp lsp'        : LANG_LISP,
+           'cl lisp'            : LANG_LISP,
+           'lsp'                : LANG_NEWLISP,
            'lt'                 : LANG_LOUT,
            'lua'                : LANG_LUA,
            'mak makefile'       : LANG_MAKE,
@@ -328,7 +335,9 @@ EXT_MAP = {
            'ini inf reg url cfg cnf' : LANG_PROPS,
            'ai ps'              : LANG_PS,
            'py pyw python'      : LANG_PYTHON,
+           'r'                  : LANG_R,        
            'rake rb rbw rbx gemspec' : LANG_RUBY,
+           's'                  : LANG_S,
            'scm smd ss'         : LANG_SCHEME,
            'sql'                : LANG_SQL,
            'nut'                : LANG_SQUIRREL,
