@@ -34,8 +34,8 @@ objects such as the Extension Register.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: syntax.py 54546 2008-07-08 03:42:50Z CJP $"
-__revision__ = "$Revision: 54546 $"
+__svnid__ = "$Id: syntax.py 56177 2008-10-09 02:03:21Z CJP $"
+__revision__ = "$Revision: 56177 $"
 
 #-----------------------------------------------------------------------------#
 # Dependencies
@@ -84,9 +84,9 @@ class SyntaxMgr(object):
         @keyword config: path of config file to load file extension config from
 
         """
-        if self.first:
+        if SyntaxMgr.first:
             object.__init__(self)
-            self.first = False
+            SyntaxMgr.first = False
             self._extreg = ExtensionRegister()
             self._config = config
             if self._config:
@@ -95,14 +95,14 @@ class SyntaxMgr(object):
                 self._extreg.LoadDefault()
             self._loaded = dict()
 
-    def __new__(cls, *args, **kargs):
+    def __new__(cls, config=None):
         """Ensure only a single instance is shared amongst
         all objects.
         @return: class instance
 
         """
-        if not cls.instance:
-            cls.instance = object.__new__(cls, *args, **kargs)
+        if cls.instance is None:
+            cls.instance = object.__new__(cls)
         return cls.instance
 
     def _ExtToMod(self, ext):
@@ -150,7 +150,7 @@ class SyntaxMgr(object):
             try:
                 self._loaded[modname] = __import__(modname, globals(), 
                                                    locals(), [''])
-            except ImportError:
+            except ImportError, msg:
                 return False
         return True
 
@@ -222,7 +222,7 @@ def GenLexerMenu():
     for key in synglob.LANG_MAP:
         f_types[key] = synglob.LANG_MAP[key][LANG_ID]
     f_order = list(f_types)
-    f_order.sort()
+    f_order.sort(NoCaseCmp)
 
     for lang in f_order:
         lex_menu.Append(f_types[lang], lang, 
@@ -246,7 +246,7 @@ def GenFileFilters():
     for key in f_dict:
         tmp = u" (%s)|%s|" % (f_dict[key][1:], f_dict[key][1:])
         filters.append(key + tmp)
-    filters.sort()
+    filters.sort(NoCaseCmp)
     filters.insert(0, u"All Files (*)|*|")
     filters[-1] = filters[-1][:-1] # IMPORTANT trim last '|' from item in list
     return filters
@@ -292,6 +292,20 @@ def GetExtFromId(ext_id):
     ftype = synglob.GetDescriptionFromId(ext_id)
     return extreg[ftype][0]
 
+def GetFtypeDisplayName(lang_id):
+    """Get the file type display string for the given lang_id
+    @param lang_id: ID_LANG_*
+    @todo: make file types translatable
+
+    """
+    for item in dir(synglob):
+        if item.startswith("ID_LANG"):
+            if getattr(synglob, item) == lang_id:
+                return getattr(synglob, item[3:], u"Plain Text")
+    else:
+        return u"Plain Text"
+
+
 def GetIdFromExt(ext):
     """Get the language id from the given file extension
     @param ext: file extension (no dot)
@@ -313,3 +327,14 @@ def GetTypeFromExt(ext):
 
     """
     return ExtensionRegister().FileTypeFromExt(ext)
+
+#-----------------------------------------------------------------------------#
+# Utility
+def NoCaseCmp(x, y):
+    """Case insensitive sort method"""
+    if x.lower() < y.lower():
+        return -1
+    elif x.lower() > y.lower():
+        return 1
+    else:
+        return 0
